# API Reference

This page is generated from source code docstrings and signatures via `mkdocstrings`.

## Package

::: telegras

## Key modules

::: telegras.app

::: telegras.telegram_api

::: telegras.webhook_attachments

::: telegras.default_handlers

::: telegras.persistence.repository
